@@ -376,7 +376,7 @@ class GSDBS:
 
         api_call_headers = {'Authorization': 'Bearer ' + self.accessToken['access_token']}
         client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql",
-                        headers=api_call_headers),
+                        headers=api_call_headers, timeout=3600),
                         fetch_schema_from_transport=False)
 
         try:
@@ -396,7 +396,7 @@ class GSDBS:
 
         api_call_headers = {'Authorization': 'Bearer ' + self.accessToken['access_token']}
         client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql",
-                        headers=api_call_headers),
+                        headers=api_call_headers, timeout=3600),
                         fetch_schema_from_transport=False)
 
         try:
